<?php

namespace Drupal\path_alias_view_access\Hook;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Hook\Attribute\Hook;
use Drupal\Core\Session\AccountInterface;

/**
 * Contains hook implementations for the Path Alias View Access module.
 */
class PathAliasViewAccessHooks {

  /**
   * Implements hook_ENTITY_TYPE_access().
   */
  #[Hook('path_alias_access')]
  public function pathAliasAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    // Grant view access for our permission.
    if ($operation == 'view') {
      return AccessResult::allowedIf($account->hasPermission('access path_aliases') && $entity->isPublished())->cachePerPermissions()->addCacheableDependency($entity);
    }
    else {
      // No opinion.
      return AccessResult::neutral();
    }
  }

  /**
   * Implements hook_jsonapi_ENTITY_TYPE_filter_access().
   */
  #[Hook('jsonapi_path_alias_filter_access')]
  public function jsonapiPathAliasFilterAccess(EntityTypeInterface $entity_type, AccountInterface $account) {
    return ([
      JSONAPI_FILTER_AMONG_ALL => AccessResult::neutral(),
      JSONAPI_FILTER_AMONG_PUBLISHED => AccessResult::allowedIfHasPermission($account, 'access path_aliases'),
      JSONAPI_FILTER_AMONG_OWN => AccessResult::allowedIfHasPermission($account, 'access path_aliases'),
    ]);
  }

}
